@@ -483,6 +483,7 @@ class CmdInterface:
             tar = tarfile.open(CmdInterface.__logfile_name.replace('.json', '_' + CmdInterface.__run_id + '.tar'), "a")
 
         self.__log['call_stack'] = list()
+        packed_files = []
         for frame in inspect.stack()[1:]:
             el = dict()
             el['file'] = os.path.abspath(str(frame[1]))
@@ -490,7 +491,8 @@ class CmdInterface:
             el['function'] = str(frame[3])
             self.__log['call_stack'].append(el)
 
-            if tar is not None and not el['file'].__contains__('site-packages'):
+            if tar is not None and not el['file'].__contains__('site-packages') and not el['file'] in packed_files:
+                packed_files.append(el['file'])
                 file_name = os.path.basename(el['file'])
                 if file_name != 'CmdInterface.py':
                     tar.add(name=el['file'], arcname=el['file'])
@@ -716,6 +718,9 @@ class CmdInterface:
             raise OSError(proc.returncode, 'Command line subprocess return value is ' + str(proc.returncode))
 
     def get_runlogs(self) -> list:
+        """
+        Load list of run logs and append new run id if necessary.
+        """
 
         if CmdInterface.__logfile_name is None or self.__no_new_log:
             return None
@@ -735,7 +740,7 @@ class CmdInterface:
 
     def update_log(self):
         """
-        Replace last entry of the json logfile by log of current instance.
+        Replace last entry of the command log list in the current run log and write to json.
         """
         run_logs = self.get_runlogs()
         if run_logs is None:
@@ -778,7 +783,7 @@ class CmdInterface:
 
     def append_log(self):
         """
-        Append log of current instance to the output json file. Creates new json if it does not exist.
+        Append command log to the list held in the run log and write to file. Creates new json if it does not exist.
         """
         run_logs = self.get_runlogs()
         if run_logs is None:
@@ -793,7 +798,6 @@ class CmdInterface:
         self.__log['options']['no_key'] = CmdInterface.__jsonable(self.__no_key_options[1:])
         self.__log['options']['key_val'] = CmdInterface.__jsonable(self.__options)
 
-
         try:
             run_logs[-1]['commands'].append(self.__log)
             with open(CmdInterface.__logfile_name, 'w') as f:
